@@ -13,17 +13,18 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from neutron.agent.linux import iptables_manager
+from neutron.common import utils
+from neutron_lib.exceptions import firewall_v1 as f_exc
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
 
-from neutron.agent.linux import iptables_manager
-from neutron.common import utils
 from neutron_fwaas._i18n import _LE
 from neutron_fwaas.common import fwaas_constants as f_const
-from neutron_fwaas.extensions import firewall as fw_ext
 from neutron_fwaas.services.firewall.drivers import fwaas_base
 
+
 LOG = logging.getLogger(__name__)
 FWAAS_DRIVER_NAME = 'Fwaas iptables driver'
 FWAAS_DEFAULT_CHAIN = 'fwaas-default-policy'
@@ -94,7 +95,7 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
         except (LookupError, RuntimeError):
             # catch known library exceptions and raise Fwaas generic exception
             LOG.exception(_LE("Failed to create firewall: %s"), firewall['id'])
-            raise fw_ext.FirewallInternalDriverError(driver=FWAAS_DRIVER_NAME)
+            raise f_exc.FirewallInternalDriverError(driver=FWAAS_DRIVER_NAME)
 
     def _get_ipt_mgrs_with_if_prefix(self, agent_mode, router_info):
         """Gets the iptables manager along with the if prefix to apply rules.
@@ -115,7 +116,7 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
             if router_info.snat_iptables_manager:
                 ipt_mgrs.append({'ipt': router_info.snat_iptables_manager,
                                  'if_prefix': SNAT_INT_DEV_PREFIX})
-        if router_info.dist_fip_count:
+        if router_info.rtr_fip_connect:
             # handle the fip case on n/w or compute node.
             ipt_mgrs.append({'ipt': router_info.iptables_manager,
                              'if_prefix': ROUTER_2_FIP_DEV_PREFIX})
@@ -139,7 +140,7 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
         except (LookupError, RuntimeError):
             # catch known library exceptions and raise Fwaas generic exception
             LOG.exception(_LE("Failed to delete firewall: %s"), fwid)
-            raise fw_ext.FirewallInternalDriverError(driver=FWAAS_DRIVER_NAME)
+            raise f_exc.FirewallInternalDriverError(driver=FWAAS_DRIVER_NAME)
 
     def update_firewall(self, agent_mode, apply_list, firewall):
         LOG.debug('Updating firewall %(fw_id)s for tenant %(tid)s',
@@ -159,7 +160,7 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
         except (LookupError, RuntimeError):
             # catch known library exceptions and raise Fwaas generic exception
             LOG.exception(_LE("Failed to update firewall: %s"), firewall['id'])
-            raise fw_ext.FirewallInternalDriverError(driver=FWAAS_DRIVER_NAME)
+            raise f_exc.FirewallInternalDriverError(driver=FWAAS_DRIVER_NAME)
 
     def apply_default_policy(self, agent_mode, apply_list, firewall):
         LOG.debug('Applying firewall %(fw_id)s for tenant %(tid)s',
@@ -185,7 +186,7 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
             # catch known library exceptions and raise Fwaas generic exception
             LOG.exception(
                 _LE("Failed to apply default policy on firewall: %s"), fwid)
-            raise fw_ext.FirewallInternalDriverError(driver=FWAAS_DRIVER_NAME)
+            raise f_exc.FirewallInternalDriverError(driver=FWAAS_DRIVER_NAME)
 
     def _setup_firewall(self, agent_mode, apply_list, firewall):
         fwid = firewall['id']
@@ -266,15 +267,11 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
         return changed_rules
 
     def _find_removed_rules(self, pre_firewall, firewall):
-        removed_rules = []
         fw_rules_list = firewall[f_const.FIREWALL_RULE_LIST]
         pre_fw_rules_list = pre_firewall[f_const.FIREWALL_RULE_LIST]
-        fw_rule_ids = []
-        for fw_rule in fw_rules_list:
-            fw_rule_ids.append(fw_rule.get('id'))
-        for pre_fw_rule in pre_fw_rules_list:
-            if pre_fw_rule.get('id') not in fw_rule_ids:
-                removed_rules.append(pre_fw_rule)
+        fw_rule_ids = [fw_rule.get('id') for fw_rule in fw_rules_list]
+        removed_rules = [pre_fw_rule for pre_fw_rule in
+            pre_fw_rules_list if pre_fw_rule.get('id') not in fw_rule_ids]
         return removed_rules
 
     def _find_new_rules(self, pre_firewall, firewall):
@@ -370,26 +367,29 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
     def _convert_fwaas_to_iptables_rule(self, rule):
         action = FWAAS_TO_IPTABLE_ACTION_MAP[rule.get('action')]
 
+        # Output ordering is important here as it must exactly match what
+        # is returned by iptables-save.  If not we risk unnecessarily removing
+        # and readding rules.
         args = []
 
         args += self._protocol_arg(rule.get('protocol'))
 
+        args += self._ip_prefix_arg('s', rule.get('source_ip_address'))
+        args += self._ip_prefix_arg('d', rule.get('destination_ip_address'))
+
         # iptables adds '-m protocol' when any source
         # or destination port number is specified
-        if not((rule.get('source_port') is None)
-           and (rule.get('destination_port') is None)):
-                args += self._match_arg(rule.get('protocol'))
-
-        args += self._port_arg('dport',
-                               rule.get('protocol'),
-                               rule.get('destination_port'))
+        if (rule.get('source_port') is not None or
+            rule.get('destination_port') is not None):
+            args += self._match_arg(rule.get('protocol'))
 
         args += self._port_arg('sport',
                                rule.get('protocol'),
                                rule.get('source_port'))
 
-        args += self._ip_prefix_arg('s', rule.get('source_ip_address'))
-        args += self._ip_prefix_arg('d', rule.get('destination_ip_address'))
+        args += self._port_arg('dport',
+                               rule.get('protocol'),
+                               rule.get('destination_port'))
 
         args += self._action_arg(action)
 
@@ -400,7 +400,7 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
         return '-m state --state INVALID -j DROP'
 
     def _allow_established_rule(self):
-        return '-m state --state ESTABLISHED,RELATED -j ACCEPT'
+        return '-m state --state RELATED,ESTABLISHED -j ACCEPT'
 
     def _action_arg(self, action):
         if not action:
@@ -430,8 +430,7 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
         return args
 
     def _port_arg(self, direction, protocol, port):
-        if (protocol not in ['udp', 'tcp']
-            or port is None):
+        if protocol not in ['udp', 'tcp'] or port is None:
             return []
 
         args = ['--%s' % direction, '%s' % port]
@@ -442,5 +441,5 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
         if not(ip_prefix):
             return []
 
-        args = ['-%s' % direction, '%s' % ip_prefix]
+        args = ['-%s' % direction, '%s' % utils.ip_to_cidr(ip_prefix)]
         return args
