@@ -13,13 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron_lib import constants as nl_constants
-from neutron_lib.plugins import directory
-
 from neutron.common import rpc as n_rpc
 from neutron.common import utils as n_utils
-from neutron import context as neutron_context
-
+from neutron_lib.api.definitions import firewall as fw_ext
+from neutron_lib import constants as nl_constants
+from neutron_lib import context as neutron_context
+from neutron_lib.exceptions import firewall_v1 as f_exc
+from neutron_lib.plugins import constants as plugin_constants
+from neutron_lib.plugins import directory
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging
@@ -28,7 +29,6 @@ from neutron_fwaas._i18n import _LI, _LW
 from neutron_fwaas.common import fwaas_constants as f_const
 from neutron_fwaas.db.firewall import firewall_db
 from neutron_fwaas.db.firewall import firewall_router_insertion_db
-from neutron_fwaas.extensions import firewall as fw_ext
 
 
 LOG = logging.getLogger(__name__)
@@ -43,7 +43,7 @@ class FirewallCallbacks(object):
 
     def set_firewall_status(self, context, firewall_id, status, **kwargs):
         """Agent uses this to set a firewall's status."""
-        LOG.debug("Setting firewall %s to status: %s" % (firewall_id, status))
+        LOG.debug("Setting firewall %s to status: %s", firewall_id, status)
         # Sanitize status first
         if status in (nl_constants.ACTIVE, nl_constants.DOWN,
                       nl_constants.INACTIVE):
@@ -58,7 +58,7 @@ class FirewallCallbacks(object):
             context, firewall_id, to_update,
             not_in=(nl_constants.PENDING_DELETE,))
         if updated:
-            LOG.debug("firewall %s status set: %s" % (firewall_id, to_update))
+            LOG.debug("firewall %s status set: %s", firewall_id, to_update)
         return updated and to_update != nl_constants.ERROR
 
     def firewall_deleted(self, context, firewall_id, **kwargs):
@@ -78,7 +78,7 @@ class FirewallCallbacks(object):
                                 {'fw': firewall_id, 'status': fw_db.status})
                     fw_db.update({"status": nl_constants.ERROR})
                     return False
-        except fw_ext.FirewallNotFound:
+        except f_exc.FirewallNotFound:
             LOG.info(_LI('Firewall %s already deleted'), firewall_id)
             return True
 
@@ -91,21 +91,13 @@ class FirewallCallbacks(object):
                 context, fw['id'])
             if fw['status'] == nl_constants.PENDING_DELETE:
                 fw_with_rules['add-router-ids'] = []
-                fw_with_rules['del-router-ids'] = (
-                    self.plugin.get_firewall_routers(context, fw['id']))
+                fw_with_rules['del-router-ids'] = fw['router_ids']
             else:
-                fw_with_rules['add-router-ids'] = (
-                    self.plugin.get_firewall_routers(context, fw['id']))
+                fw_with_rules['add-router-ids'] = fw['router_ids']
                 fw_with_rules['del-router-ids'] = []
             fw_list.append(fw_with_rules)
         return fw_list
 
-    def get_firewalls_for_tenant_without_rules(self, context, **kwargs):
-        """Agent uses this to get all firewalls for a tenant."""
-        LOG.debug("get_firewalls_for_tenant_without_rules() called")
-        fw_list = [fw for fw in self.plugin.get_firewalls(context)]
-        return fw_list
-
     def get_tenants_with_firewalls(self, context, **kwargs):
         """Agent uses this to get all tenants that have firewalls."""
         LOG.debug("get_tenants_with_firewalls() called")
@@ -160,7 +152,7 @@ class FirewallPlugin(
     firewall_db.Firewall_db_mixin.
     """
     supported_extension_aliases = ["fwaas", "fwaasrouterinsertion"]
-    path_prefix = fw_ext.FIREWALL_PREFIX
+    path_prefix = fw_ext.API_PREFIX
 
     def __init__(self):
         """Do the initialization for the firewall service plugin here."""
@@ -182,7 +174,7 @@ class FirewallPlugin(
 
     def _get_hosts_to_notify(self, context, router_ids):
         """Returns all hosts to send notification about firewall update"""
-        l3_plugin = directory.get_plugin(nl_constants.L3)
+        l3_plugin = directory.get_plugin(plugin_constants.L3)
         no_broadcast = (
             n_utils.is_extension_supported(
                 l3_plugin, nl_constants.L3_AGENT_SCHEDULER_EXT_ALIAS) and
@@ -223,8 +215,8 @@ class FirewallPlugin(
         if fwall['status'] in [nl_constants.PENDING_CREATE,
                                nl_constants.PENDING_UPDATE,
                                nl_constants.PENDING_DELETE]:
-            raise fw_ext.FirewallInPendingState(firewall_id=firewall_id,
-                                                pending_state=fwall['status'])
+            raise f_exc.FirewallInPendingState(firewall_id=firewall_id,
+                                               pending_state=fwall['status'])
 
     def _ensure_update_firewall_policy(self, context, firewall_policy_id):
         firewall_policy = self.get_firewall_policy(context, firewall_policy_id)
@@ -245,7 +237,7 @@ class FirewallPlugin(
         if router_ids == nl_constants.ATTR_NOT_SPECIFIED:
             # old semantics router-ids keyword not specified pick up
             # all routers on tenant.
-            l3_plugin = directory.get_plugin(nl_constants.L3)
+            l3_plugin = directory.get_plugin(plugin_constants.L3)
             ctx = neutron_context.get_admin_context()
             routers = l3_plugin.get_routers(ctx)
             router_ids = [
@@ -306,7 +298,8 @@ class FirewallPlugin(
         # pop router_id as this goes in the router association db
         # and not firewall db
         router_ids = firewall['firewall'].pop('router_ids', None)
-        fw_current_rtrs = self.get_firewall_routers(context, id)
+        fw_current_rtrs = fw_new_rtrs = self.get_firewall_routers(
+            context, id)
         if router_ids is not None:
             if router_ids == []:
                 # This indicates that user is indicating no routers.
@@ -317,10 +310,6 @@ class FirewallPlugin(
                 fw_new_rtrs = router_ids
             self.update_firewall_routers(context, {'fw_id': id,
                 'router_ids': fw_new_rtrs})
-        else:
-            # router-ids keyword not specified for update pick up
-            # existing routers.
-            fw_new_rtrs = self.get_firewall_routers(context, id)
 
         if not fw_new_rtrs and not fw_current_rtrs:
             # no messaging to agent needed, and we need to continue
