@@ -12,11 +12,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron_lib.plugins import directory
-
 from neutron.common import rpc as n_rpc
-from neutron import context as neutron_context
+from neutron.db import servicetype_db as st_db
+from neutron.services import provider_configuration as provider_conf
+from neutron_lib.api.definitions import firewall_v2
 from neutron_lib import constants as nl_constants
+from neutron_lib import context as neutron_context
+from neutron_lib.exceptions import firewall_v2 as f_exc
+from neutron_lib.plugins import constants as plugin_const
+from neutron_lib.plugins import directory
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging
@@ -24,12 +28,17 @@ import oslo_messaging
 from neutron_fwaas._i18n import _LI
 from neutron_fwaas.common import fwaas_constants
 from neutron_fwaas.db.firewall.v2 import firewall_db_v2
-from neutron_fwaas.extensions import firewall_v2 as fw_ext
 
 
 LOG = logging.getLogger(__name__)
 
 
+def add_provider_configuration(type_manager, service_type):
+    type_manager.add_provider_configuration(
+        service_type,
+        provider_conf.ProviderConfiguration('neutron_fwaas'))
+
+
 class FirewallAgentApi(object):
     """Plugin side of plugin to agent RPC API."""
 
@@ -66,8 +75,8 @@ class FirewallCallbacks(object):
 
     def set_firewall_group_status(self, context, fwg_id, status, **kwargs):
         """Agent uses this to set a firewall_group's status."""
-        LOG.debug("Setting firewall_group %s to status: %s" % (
-            fwg_id, status))
+        LOG.debug("Setting firewall_group %s to status: %s",
+                  fwg_id, status)
         # Sanitize status first
         if status in (nl_constants.ACTIVE, nl_constants.DOWN,
                       nl_constants.INACTIVE):
@@ -81,7 +90,7 @@ class FirewallCallbacks(object):
         updated = self.plugin.update_firewall_group_status(
             context, fwg_id, to_update, not_in=(nl_constants.PENDING_DELETE,))
         if updated:
-            LOG.debug("firewall %s status set: %s" % (fwg_id, to_update))
+            LOG.debug("firewall %s status set: %s", fwg_id, to_update)
         return updated and to_update != nl_constants.ERROR
 
     def firewall_group_deleted(self, context, fwg_id, **kwargs):
@@ -102,7 +111,7 @@ class FirewallCallbacks(object):
                                 {'fwg': fwg_id, 'status': fwg_db.status})
                     fwg_db.update({"status": nl_constants.ERROR})
                     return False
-        except fw_ext.FirewallGroupNotFound:
+        except f_exc.FirewallGroupNotFound:
             LOG.info(_LI('Firewall group %s already deleted'), fwg_id)
             return True
 
@@ -144,10 +153,13 @@ class FirewallPluginV2(
     firewall_db_v2.Firewall_db_mixin_v2.
     """
     supported_extension_aliases = ["fwaas_v2"]
-    path_prefix = fw_ext.FIREWALL_PREFIX
+    path_prefix = firewall_v2.API_PREFIX
 
     def __init__(self):
         """Do the initialization for the firewall service plugin here."""
+        self.service_type_manager = st_db.ServiceTypeManager.get_instance()
+        add_provider_configuration(
+            self.service_type_manager, plugin_const.FIREWALL)
         self.start_rpc_listeners()
 
         self.agent_rpc = FirewallAgentApi(
@@ -194,7 +206,7 @@ class FirewallPluginV2(
         if fwg['status'] in [nl_constants.PENDING_CREATE,
                              nl_constants.PENDING_UPDATE,
                              nl_constants.PENDING_DELETE]:
-            raise fw_ext.FirewallGroupInPendingState(firewall_id=fwg_id,
+            raise f_exc.FirewallGroupInPendingState(firewall_id=fwg_id,
                                                 pending_state=fwg['status'])
 
     def _ensure_update_firewall_policy(self, context, firewall_policy_id):
@@ -216,10 +228,10 @@ class FirewallPluginV2(
         for port_id in fwg_ports:
             port_db = self._core_plugin._get_port(context, port_id)
             if port_db['device_owner'] != "network:router_interface":
-                raise fw_ext.FirewallGroupPortInvalid(port_id=port_id)
+                raise f_exc.FirewallGroupPortInvalid(port_id=port_id)
             if port_db['tenant_id'] != tenant_id:
-                raise fw_ext.FirewallGroupPortInvalidProject(
-                    port_id=port_id, tenant_id=port_db['tenant_id'])
+                raise f_exc.FirewallGroupPortInvalidProject(
+                    port_id=port_id, project_id=port_db['tenant_id'])
         return
 
     def _check_no_need_pending(self, context, fwg_id, fwg_body):
@@ -281,7 +293,8 @@ class FirewallPluginV2(
         self._ensure_update_firewall_group(context, id)
 
         # TODO(sridar): need closure on status when no policy associated.
-        fwg_current_ports = self._get_ports_in_firewall_group(context, id)
+        fwg_current_ports = fwg_new_ports = self._get_ports_in_firewall_group(
+            context, id)
         if 'ports' in firewall_group['firewall_group']:
             fwg_ports = firewall_group['firewall_group']['ports']
             if fwg_ports == []:
@@ -293,10 +306,6 @@ class FirewallPluginV2(
                 self._validate_if_firewall_group_on_ports(
                     context, fwg_ports, id)
                 fwg_new_ports = fwg_ports
-        else:
-            # ports keyword not specified for update pick up
-            # existing ports.
-            fwg_new_ports = self._get_ports_in_firewall_group(context, id)
 
         if ((not fwg_new_ports and not fwg_current_ports) or
             self._check_no_need_pending(context,
@@ -379,3 +388,19 @@ class FirewallPluginV2(
         for fwp_id in fwp_ids:
             self._rpc_update_firewall_policy(context, fwp_id)
         return fwr
+
+    def insert_rule(self, context, policy_id, rule_info):
+        LOG.debug("insert_rule() called for policy %s ", policy_id)
+        self._ensure_update_firewall_policy(context, policy_id)
+        fwp = super(FirewallPluginV2, self).insert_rule(context, policy_id,
+                                                        rule_info)
+        self._rpc_update_firewall_policy(context, policy_id)
+        return fwp
+
+    def remove_rule(self, context, policy_id, rule_info):
+        LOG.debug("remove_rule() called for policy %s ", policy_id)
+        self._ensure_update_firewall_policy(context, policy_id)
+        fwp = super(FirewallPluginV2, self).remove_rule(context, policy_id,
+                                                        rule_info)
+        self._rpc_update_firewall_policy(context, policy_id)
+        return fwp
