@@ -65,7 +65,7 @@ class TestFWaaS_v2(base.FWaaSScenarioTest_V2):
     def _check_connectivity_between_internal_networks(
             self, floating_ip1, keys1, network2, server2, should_connect=True):
         internal_ips = (p['fixed_ips'][0]['ip_address'] for p in
-                        self.admin_manager.ports_client.list_ports(
+                        self.os_admin.ports_client.list_ports(
                             tenant_id=server2['tenant_id'],
                             network_id=network2['id'])['ports']
                         if p['device_owner'].startswith('network'))
@@ -98,6 +98,7 @@ class TestFWaaS_v2(base.FWaaSScenarioTest_V2):
     def _check_remote_connectivity(self, source, dest, should_succeed=True,
                                    nic=None):
         """check ping server via source ssh connection
+
         :param source: RemoteClient: an ssh connection from which to ping
         :param dest: and IP to ping against
         :param should_succeed: boolean should ping succeed or not
@@ -110,7 +111,7 @@ class TestFWaaS_v2(base.FWaaSScenarioTest_V2):
                 source.ping_host(dest, nic=nic)
             except lib_exc.SSHExecCommandFailed:
                 LOG.warning('Failed to ping IP: %s via a ssh connection '
-                            'from: %s.' % (dest, source.ssh_client.host))
+                            'from: %s.', dest, source.ssh_client.host)
                 return not should_succeed
             return should_succeed
 
@@ -139,7 +140,6 @@ class TestFWaaS_v2(base.FWaaSScenarioTest_V2):
         private_key = keys['private_key']
         server_floating_ip = self.create_floating_ip(server, pub_network_id)
         fixed_ip = server['addresses'].values()[0][0]['addr']
-        #floating_ip = server_floating_ip['floating_ip_address']
         return server, private_key, fixed_ip, server_floating_ip
 
     def _create_topology(self):
@@ -223,8 +223,13 @@ class TestFWaaS_v2(base.FWaaSScenarioTest_V2):
             private_key=topology['private_key2'])
 
         # Scenario 1: Add allow ICMP rules between the two VMs.
-        fw_rule = self.create_firewall_rule(action="allow", protocol="icmp")
-        fw_policy = self.create_firewall_policy(firewall_rules=[fw_rule['id']])
+        fw_allow_icmp_rule = self.create_firewall_rule(action="allow",
+                                                       protocol="icmp")
+        fw_allow_ssh_rule = self.create_firewall_rule(action="allow",
+                                                      protocol="tcp",
+                                                      destination_port=22)
+        fw_policy = self.create_firewall_policy(
+            firewall_rules=[fw_allow_icmp_rule['id'], fw_allow_ssh_rule['id']])
         fw_group = self.create_firewall_group(
             ports=[
                 topology['router_portid_1'],
@@ -232,14 +237,31 @@ class TestFWaaS_v2(base.FWaaSScenarioTest_V2):
             ingress_firewall_policy_id=fw_policy['id'],
             egress_firewall_policy_id=fw_policy['id'])
         self._wait_firewall_group_ready(fw_group['id'])
-        LOG.debug(
-            'fw_rule: %s\nfw_policy: %s\nfw_group: %s\n' %
-            (fw_rule, fw_policy, fw_group))
+        LOG.debug('fw_allow_icmp_rule: %s\nfw_allow_ssh_rule: %s\n'
+                  'fw_policy: %s\nfw_group: %s\n',
+                  fw_allow_icmp_rule, fw_allow_ssh_rule, fw_policy, fw_group)
 
         # Check the connectivity between VM1 and VM2. It should Pass.
-        self._check_connectivity_between_internal_networks(
+        self._check_server_connectivity(
             topology['server_floating_ip_1'],
             topology['private_key1'],
-            topology['network2'],
-            topology['server2'],
+            address_list=[topology['server_fixed_ip_2']],
             should_connect=True)
+
+        # Now remove the allow_icmp rule add a deny_icmp rule and check that
+        # ICMP gets blocked
+        fw_deny_icmp_rule = self.create_firewall_rule(action="deny",
+                                                      protocol="icmp")
+        self.remove_firewall_rule_from_policy(
+            firewall_rule_id=fw_allow_icmp_rule['id'],
+            firewall_policy_id=fw_policy['id'])
+        self._wait_firewall_group_ready(fw_group['id'])
+        self.insert_firewall_rule_in_policy(
+            firewall_rule_id=fw_deny_icmp_rule['id'],
+            firewall_policy_id=fw_policy['id'])
+        self._wait_firewall_group_ready(fw_group['id'])
+        self._check_server_connectivity(
+            topology['server_floating_ip_1'],
+            topology['private_key1'],
+            address_list=[topology['server_fixed_ip_2']],
+            should_connect=False)
