@@ -14,7 +14,7 @@
 # pip install {opts} {packages}
 
 ZUUL_CLONER=/usr/zuul-env/bin/zuul-cloner
-BRANCH_NAME=stable/ocata
+BRANCH_NAME=stable/pike
 neutron_installed=$(echo "import neutron" | python 2>/dev/null ; echo $?)
 NEUTRON_DIR=$HOME/neutron
 
@@ -24,6 +24,8 @@ set -x
 install_cmd="pip install -c$1"
 shift
 
+PARAMS="$*"
+
 # The devstack based functional tests have neutron checked out in
 # $NEUTRON_DIR on the test systems - with the change to test in it.
 # Use this directory if it exists, so that this script installs the
@@ -58,11 +60,16 @@ elif [ -x "$ZUUL_CLONER" ]; then
     popd
 else
     echo "PIP HARDCODE" > /tmp/tox_install.txt
-    if [ -z "$NEUTRON_PIP_LOCATION" ]; then
-        NEUTRON_PIP_LOCATION="git+https://git.openstack.org/openstack/neutron@$BRANCH_NAME#egg=neutron"
+    if [ -z "$NEUTRON_GIT_REPO" ]; then
+        NEUTRON_GIT_REPO="https://git.openstack.org/openstack/neutron"
     fi
-    $install_cmd -U -e ${NEUTRON_PIP_LOCATION}
+    SRC_DIR="$VIRTUAL_ENV/src/neutron"
+    git clone --depth 1 --branch $BRANCH_NAME $NEUTRON_GIT_REPO $SRC_DIR
+    $install_cmd -U -e $SRC_DIR
+fi
+
+if [ -n "${PARAMS}" ]; then
+   $install_cmd -U ${PARAMS}
 fi
 
-$install_cmd -U $*
 exit $?
